from dataclasses import dataclass

from devsecops_engine_tools.engine_core.src.domain.model.input_core import InputCore


@dataclass
class VulnerabilityManagement:
    scan_type: str
    input_core: InputCore
    dict_args: any
    secret_tool: any
    config_tool: any
    source_code_management_uri: str
    base_compact_remote_config_url: str
    access_token: str
    version: str
    build_id: str
    branch_tag: str
    commit_hash: str
    environment: str
    vm_product_type_name: str
    vm_product_name: str
    vm_product_description: str
